/* Sample code, variant 1 to show the use of glylib.  
Begun on 20100215 by BLFoley.

Purpose:
	* Read in an amber prmtop file.
	* Find all carbon atoms bound to hydroxyl oxygens.
	* Change these carbons to C-13 in name and mass
	* Well assume no other changes to the prmtop are needed
	* Write out a new prmtop with the changed info
*/

#include <glylib.h> /* import glylib headers ... glylib.h is still
				in development.  Currently must load
				several .h files.  Can always load 
				only the ones you need */
#include <AMBER/amber.h> /* import AMBER-specific headers */

#define TC13 "CG13"	/* Our new type for the C13 atom */
#define mC13 13.00335	/* Mass of C13 in amu */

/* A standard usage statement */
#define USAGE "change_C_types amber_prmtop.top"

/* All C programs start off at the function called "main" */
int main(int argc, char *argv[]) { /* standard main function */

/* First, we need to declare some variables */

/* These variables are standard C variable types */
int mi,ri,ai,bi; 	/* some counting indices */

/* These are GLYLIB types */
/*fileset OF;*/
fileset IF; 		/* Input and output file info
			contains file name and pointer
			this simplifies file error reporting */
assembly A; 		/* an empty, unititialized assembly */
molindex moli;		/* a molecule index ... m,r,a indices */
molecule *mtmp;		/* Pointer to a molecule (for convenience) */
residue *rtmp;		/* Pointer to a residue (for convenience) */
atom *atmp,*a2tmp; 	/* Pointers to atom (for convenience) */
/* It is always good to check the command line sanity */
/* glylib contains many convenience functions, for example: */
if(argc<2){mywhineusage("Need input prmtop file name.",USAGE);}

/* copy the input file name to a convenient location */
/* this is convenient, not efficient or necessary */
IF.N = strdup(argv[1]); 	/* Copy name of input file */


/* Now, load in the contents of the amber prmtop file */
/* load_amber_prmtop requires the file not be open already */
A = load_amber_prmtop(IF); 	/* initializes assembly, reads
					file, allocates memory,
					parses file, etc. */

/* Make a simple check see if things went well */
if(A.nm<1){mywhine("No molecules found in prmtop file!");}
for(mi=0;mi<A.nm;mi++){ /* for each molecule */
	mtmp=A.m[mi]; /* set pointer for code-reading ease */

	for(ri=0;ri < mtmp[0].nr;ri++){ /* each residue */
		rtmp = &mtmp[0].r[ri]; /* note ampersand */

		for(ai=0;ai < rtmp[0].na;ai++){ /* atom */
			atmp =&rtmp[0].a[ai]; 

if( atmp[0].T[0] =='C'){ /* if a carbon atom (& behaved names) 
				NOTE single quotes*/
for(bi=0;bi<atmp[0].nmb;bi++){ /* for each bond */
	moli=atmp[0].mb[bi].t; /* for readability, copy the moli 
				of the target atom in the bond */
	a2tmp=&A.m[moli.m][0].r[moli.r].a[moli.a]; /* set a pointer
					to this bound atom */ 
	if (strcmp(a2tmp[0].T,"OH")==0){ /* if a hydroxyl O */ 
		free(atmp[0].T); /* clear current entry */ 
		atmp[0].T = strdup(TC13); /* set new type name */
		atmp[0].m = mC13; /* set new atom mass */
/* in lieu of a functioning write prmtop subroutine, print info 
	to prove something happened */
printf("Changed type of atom name %s (file # %d) in residue %s (file # %d)\n",\
	atmp[0].N,atmp[0].n,rtmp[0].N,rtmp[0].n);
printf("\t Glylib molecule index is m=%d r=%d a=%d ; OH-bond index is %d\n",mi,ri,ai,bi);
		} /* close if hydroxyl */
	} /* close bond loop */
	} /* close if is a carbon condition */

			} /* close atom loop */
		} /* close residue loop */
	} /* close molecule loop */

/* this function hasn't been written yet... */
/* OF.N=strdup("output.prmtop"); 
write_amber_prmtop_from_assembly(OF,&A); */

return 0; /* indicate successful completion */
}

